%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%											
%   "Copyright (c) 2011 David I Shuman"				
%   All rights reserved.
%
%   This is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   This code is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   If you do not have a copy of the GNU General Public License,
%   see <http://www.gnu.org/licenses/>.									
%											
%   Authors: David I Shuman and Javier Prez-Trufero
%   Signal Processing Laboratories LTS2 and LTS4
%   cole Polytechnique Fdrale de Lausanne (EPFL)
%   Contact: david.shuman@epfl.ch
%
%   Date last modified:	10/12/2011 
%
%   Description:
%     This function plots a signal on a graph in a two-dimensional space, 
%     inlcuding the edges in the graph.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function plot_graph_signal(XCoords,YCoords,adj_matrix,N,signal,limits)

figure;
hold on;

% Plot signal
for i=1:N
    x_c = [XCoords(i),XCoords(i)];
    y_c= [YCoords(i),YCoords(i)];
    z_c=[0,signal(i)];
    if z_c(2) >=0
        plot3(x_c,y_c,z_c,'-b','LineWidth',1)
    else
        plot3(x_c,y_c,z_c,'-k','LineWidth',1)
    end
end

% Plot network structure
for i=1:N
    for j=1:N
        if(adj_matrix(i,j)==1)
            x = [XCoords(i) XCoords(j)];
            y = [YCoords(i) YCoords(j)];
            plot3(x,y,[0 0],'-r','LineWidth',.25); %Plot the links
        end
    end
end
hold off
axis([limits.xlow limits.xhigh limits.ylow limits.yhigh limits.zlow limits.zhigh])
axis off
view([0 50])
drawnow